API
=====

BlochBuster module
-------------------------
.. automodule:: BlochBuster
    :members:
    :undoc-members:


FFMPEGwriter module
-------------------------

.. automodule:: FFMPEGwriter
    :members:
    :undoc-members:

